/***************************************************************************
                          xpmladen.h  -  description
                             -------------------
    begin                : Mon May 28 2001
    copyright            : (C) 2001 by Immi
    email                : cuyo@karimmi.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
 
#ifndef XPMLADEN_H
#define XPMLADEN_H


#include <qimage.h>

#include "inkompatibel.h"

/* Versucht die Datei na zu laden und in QImage zu speichern.
   Versucht auerdem, die Datei na.gz zu lagen.
   Liefert false, wenn keine der Dateien existiert.
   Throwt, wenn's beim Laden einen Fehler gibt.
   (Falls die QT-Lad-Routine verwendet wird, kann nicht versucht werden,
   die .gz-Datei zu laden.) */
bool ladXPM(QImage & im, __String na);


#endif
